# frozen_string_literal: true

module Hyrax
  module CrcDatasets
    class ComplexSubjectsController < ApplicationController
      before_action :set_crc_dataset
      before_action :set_complex_subject, only: %i[show edit update]
      with_themed_layout :decide_layout

      def new
        @complex_subject = ::ComplexSubject.new
      end

      def edit; end

      def show
        @subject_members = Kaminari.paginate_array(@complex_subject.file_sets_fast_load_metadata + @complex_subject.complex_sessions).page(params[:page] || 1).per(params[:per_page] || 5)
      end

      def create
        @complex_subject = ::ComplexSubject.new(complex_subject_params.merge!({ parent_source_identifier: @crc_dataset.source.first }))

        if @complex_subject.save
          update_file_set
          message = 'Complex subject was successfully created.'
          flash[:alert] = save_alert if params[:uploaded_files].present?
          redirect_to crc_dataset_complex_subject_path(@crc_dataset, @complex_subject), notice: message
        else
          render :new
        end
      end

      def update
        if @complex_subject.update(complex_subject_params)
          update_file_set
          message = 'Complex subject was successfully updated.'
          flash[:alert] = save_alert if params[:uploaded_files].present?
          redirect_to crc_dataset_complex_subject_path(@crc_dataset, @complex_subject), notice: message
        else
          render :edit
        end
      end

      private

      def set_crc_dataset
        @crc_dataset = ::CrcDataset.find(params[:crc_dataset_id])
      end

      def set_complex_subject
        @complex_subject = ::ComplexSubject.find(params[:id])
      end

      def complex_subject_params
        params.require(:complex_subject).permit(:subject_title, :subject_species, :subject_type, :subject_sex, :subject_age)
      end

      def decide_layout
        layout = case action_name
                 when 'show'
                   '1_column'
                 else
                   'dashboard'
                 end
        File.join(theme, layout)
      end

      def update_file_set
        if params[:uploaded_files].present? and params[:uploaded_files].any?
          uploaded_files = Hyrax::UploadedFile.find(params[:uploaded_files])
          AttachFilesToWorkJob.perform_later(@crc_dataset, uploaded_files, {for_complex_identifier: @complex_subject.source_identifier, for_complex_type: 'ComplexSubject'})
        end
      end

      def save_alert
        'Your files are being processed by RDMS in the background. The metadata and access controls you specified are being applied. You may need to refresh this page to see these updates.'
      end
    end
  end
end
