# frozen_string_literal: true

# Generated via
#  `rails generate hyrax:work CrcDataset`
module Hyrax
  # Generated controller for CrcDataset
  class CrcDatasetsController < ApplicationController
    # Adds Hyrax behaviors to the controller.
    include Hyrax::WorksControllerBehavior
    include Hyrax::BreadcrumbsForWorks
    self.curation_concern_type = ::CrcDataset

    # Use this line if you want to use a custom presenter
    self.show_presenter = Hyrax::CrcDatasetPresenter

    before_action :authorize_collection_access, only: :new

    def authorize_collection_access
      group_id = params[:add_works_to_collection]

      if current_user.admin? || current_user.crc_manager_for?(group_id) || current_user.group_manager_for?(group_id) || current_user.group_member_for?(group_id)
        return true
      end

      redirect_to root_path

      flash[:alert] = 'You are not authorized to access this page.'
    end

    def new
      curation_concern.crc_work_type = 'experiment'

      set_curation_attributes_from_parent if params.key?(:parent_id) && params[:parent_id].present?

      super
    end

    private

    def set_curation_attributes_from_parent
      parent_record = CrcDataset.find(params[:parent_id])

      return unless parent_record

      curation_concern.crc_work_type = case parent_record.crc_work_type
                                       when 'experiment'
                                         'subject'
                                       when 'subject'
                                         'session'
                                       when 'session'
                                         'modality'
                                       end

      curation_concern.attributes = parent_record.attributes.slice('experiment_title', 'experiment_description',
                                                                   'approval_number', 'crc_resource_type',
                                                                   'coverage', 'extra_information')

      set_complex_person_from_parent(parent_record)

      set_complex_subject_from_parent(parent_record) if %w[subject session].include?(parent_record.crc_work_type)
    end

    def set_complex_person_from_parent(parent_record)
      parent_record.attributes['complex_person'].each do |complex_person|
        new_complex_person_record = ComplexPerson.new(RDF::Node.new, ActiveTriples::Resource.new)

        new_complex_person_record.attributes = complex_person.attributes.except(:id)

        curation_concern.complex_person << new_complex_person_record
      end
    end

    def set_complex_subject_from_parent(parent_record)
      parent_record.attributes['complex_subject'].each do |complex_subject|
        new_complex_subject_record = ComplexSubject.new(RDF::Node.new, ActiveTriples::Resource.new)

        new_complex_subject_record.attributes = complex_subject.attributes.except(:id)

        curation_concern.complex_subject << new_complex_subject_record
      end
    end
  end
end
