# frozen_string_literal: true

class ComplexSubject < ActiveRecord::Base
  has_many :complex_sessions, foreign_key: 'parent_source_identifier', primary_key: 'source_identifier'

  attribute :source_identifier, :string, default: -> { SecureRandom.uuid }

  validates :source_identifier, presence: true, uniqueness: true
  validates :parent_source_identifier, presence: true

  after_save :save_work_meta_json_file_to_s3, :reindex_crc_dataset

  def crc_dataset
    CrcDataset.where(source: parent_source_identifier).first
  end

  def file_sets
    FileSet.where(for_complex_identifier: source_identifier)
  end

  def file_sets_fast_load_metadata
    FileSetFastLoadMetadata.where(work_source_identifier: source_identifier)
  end

  private

  def reindex_crc_dataset
    Hyrax::ReindexCrcDatasetJob.perform_later(crc_dataset.id)
  end

  def save_work_meta_json_file_to_s3
    s3 = S3StorageService.new
    s3.init_client
    bucket_name = s3.sanitise_name(crc_dataset.id)
    s3.create_bucket(bucket_name) unless s3.bucket_exists?(bucket_name)
    s3.add_content(bucket_name, "#{subject_title}/metadata.json", to_json)
  end
end
