class User < ApplicationRecord
  # Connects this user object to Hydra behaviors.
  include Hydra::User
  # Connects this user object to Role-management behaviors.
  include Hydra::RoleManagement::UserRoles

  include RDMSRoles
  # Connects this user object to Hyrax behaviors.
  include Hyrax::User
  include Hyrax::UserUsageStats



  if Blacklight::Utils.needs_attr_accessible?
    attr_accessible :email, :password, :password_confirmation
  end
  # Connects this user object to Blacklights Bookmarks.
  include Blacklight::User
  # Include default devise modules. Others available are:
  # :confirmable, :lockable, :timeoutable, :trackable and :omniauthable
  devise :database_authenticatable, :registerable,
         :recoverable, :rememberable, :validatable, :omniauthable

  # Method added by Blacklight; Blacklight uses #to_s on your
  # user class to get a user-displayable login/identifier for
  # the account.
  def to_s
    email
  end

  def admin?
    roles.where(name: "admin").any?
  end

  def crc_manager_for?(group_id)
    group = Collection.find(group_id) rescue nil

    return false unless group

    roles.where(name: "#{group.collection_type.title.parameterize(separator: '_')}_manager").any?
  end

  def group_manager_for?(group_id)
    group = Collection.find(group_id) rescue nil

    return false unless group

    roles.where(name: "#{group.collection_type.title.parameterize(separator: '_')}_#{group.id}_manager").any?
  end

  def group_member_for?(group_id)
    group = Collection.find(group_id) rescue nil

    return false unless group

    roles.where(name: "#{group.collection_type.title.parameterize(separator: '_')}_#{group.id}_member").any?
  end

  def publication_manager?
    roles.where(name: "publication_manager").any?
  end

  def self.from_omniauth(auth)
    where(provider: auth.provider, uid: auth.uid).first_or_create do |user|
      user.provider = auth.provider
      if auth.provider == 'orcid'
        user.orcid == auth.uid
      end
      user.uid = auth.uid
      user.display_name = auth.info.name
      user.email = auth.info.email || "#{auth.uid}@example.com"
      user.password = Devise.friendly_token[0,20]
    end
  end

  def self.find_by_orcid(orcid)
    User.where( provider: 'orcid', uid: orcid).or(User.where(orcid: orcid)).first
  end
end
